=== modified file 'drizzled/error.cc'
--- drizzled/error.cc	2011-01-31 16:31:35 +0000
+++ drizzled/error.cc	2011-02-03 07:17:37 +0000
@@ -581,6 +581,7 @@
   ADD_ERROR_MESSAGE(ER_CORRUPT_CATALOG_DEFINITION, N_("Corrupt or invalid catalog definition for '%s' : '%s'."));
   ADD_ERROR_MESSAGE(ER_WRONG_NAME_FOR_CATALOG, N_("Invalid catalog name."));
   ADD_ERROR_MESSAGE(ER_USE_DATA_DICTIONARY, N_("Engine status is now stored in the data_dictionary tables, please use these instead."));
+  ADD_ERROR_MESSAGE(ER_TRANSACTION_ALREADY_STARTED, N_("There is already a transaction in progress"));
 
 }
 

=== modified file 'drizzled/error_t.h'
--- drizzled/error_t.h	2011-01-31 16:31:35 +0000
+++ drizzled/error_t.h	2011-02-04 00:09:09 +0000
@@ -865,9 +865,7 @@
   ER_INVALID_DATE_VALUE,
   ER_TRANSACTIONAL_DDL_NOT_SUPPORTED,
   ER_USE_DATA_DICTIONARY,
-  // Leave ER_INVALID_BOOLEAN_VALUE as LAST, and force people to use tags
-  // instead of numbers in error messages in test.
-  ER_ERROR_LAST=   ER_USE_DATA_DICTIONARY
+  ER_TRANSACTION_ALREADY_STARTED
 };
 
 

=== modified file 'drizzled/statement/start_transaction.cc'
--- drizzled/statement/start_transaction.cc	2011-01-22 07:05:32 +0000
+++ drizzled/statement/start_transaction.cc	2011-02-03 02:45:51 +0000
@@ -28,6 +28,14 @@
 
 bool statement::StartTransaction::execute()
 {
+  if (getSession()->inTransaction())
+  {
+    push_warning_printf(getSession(), DRIZZLE_ERROR::WARN_LEVEL_WARN,
+                        ER_TRANSACTION_ALREADY_STARTED,
+                        ER(ER_TRANSACTION_ALREADY_STARTED));
+    return false;
+  }
+
   if (getSession()->transaction.xid_state.xa_state != XA_NOTR)
   {
     my_error(ER_XAER_RMFAIL, MYF(0),

=== modified file 'plugin/storage_engine_api_tester/tests/r/transaction.result'
--- plugin/storage_engine_api_tester/tests/r/transaction.result	2011-01-21 01:09:12 +0000
+++ plugin/storage_engine_api_tester/tests/r/transaction.result	2011-02-03 07:17:37 +0000
@@ -64,6 +64,8 @@
 seapitester_clear_engine_state_history()
 0
 START TRANSACTION;
+Warnings:
+Warning	1747	There is already a transaction in progress
 INSERT INTO t1_trx VALUES ('key1','value1');
 INSERT INTO t1_trx VALUES ('key2','value2');
 SELECT t1_trx.k, t1_trx.v
@@ -75,13 +77,6 @@
 ROLLBACK;
 select * from data_dictionary.seapitester_engine_state_history;
 STATE
-COMMIT
-::SEAPITester()
-BEGIN
-In Transaction
-END STATEMENT
-COMMIT STATEMENT
-In Transaction
 START STATEMENT
 END STATEMENT
 COMMIT STATEMENT

=== modified file 'tests/lib/test_run_options.py'
--- tests/lib/test_run_options.py	2011-02-01 17:35:58 +0000
+++ tests/lib/test_run_options.py	2011-02-04 02:13:52 +0000
@@ -328,10 +328,6 @@
 
 parser.add_option_group(debugger_control_group)
 
-#prints entire help menu when usage message is displayed
-parser.usage= parser.print_help()
-
-
 # supplied will be those arguments matching an option, 
 # and test_cases will be everything else
 (args, test_cases)= parser.parse_args()

=== modified file 'tests/r/savepoints.result'
--- tests/r/savepoints.result	2010-12-29 04:36:52 +0000
+++ tests/r/savepoints.result	2011-02-03 07:17:37 +0000
@@ -21,6 +21,8 @@
 2
 3
 START TRANSACTION;
+Warnings:
+Warning	1747	There is already a transaction in progress
 INSERT INTO t1 VALUES (4);
 SAVEPOINT A;
 INSERT INTO t1 VALUES (5);
@@ -33,6 +35,8 @@
 2
 3
 START TRANSACTION;
+Warnings:
+Warning	1747	There is already a transaction in progress
 INSERT INTO t1 VALUES (4);
 SAVEPOINT A;
 INSERT INTO t1 VALUES (5);

=== modified file 'tests/r/transaction.result'
--- tests/r/transaction.result	2010-12-29 04:39:39 +0000
+++ tests/r/transaction.result	2011-02-03 07:17:37 +0000
@@ -26,6 +26,8 @@
 key1	value1
 key2	value2
 START TRANSACTION;
+Warnings:
+Warning	1747	There is already a transaction in progress
 INSERT INTO t1_trx VALUES ('key1','value1');
 INSERT INTO t1_trx VALUES ('key2','value2');
 SELECT t1_trx.k, t1_trx.v

=== modified file 'tests/suite/execute/r/transaction.result'
--- tests/suite/execute/r/transaction.result	2011-01-24 05:21:40 +0000
+++ tests/suite/execute/r/transaction.result	2011-02-03 07:17:37 +0000
@@ -13,6 +13,8 @@
 1
 2
 START TRANSACTION;
+Warnings:
+Warning	1747	There is already a transaction in progress
 EXECUTE @insert_var;
 ROLLBACK;
 SELECT a FROM t1;
@@ -20,6 +22,8 @@
 1
 2
 START TRANSACTION;
+Warnings:
+Warning	1747	There is already a transaction in progress
 SET @insert_var= "INSERT INTO t1 VALUES(); SELECT WILL_ERROR;";
 EXECUTE @insert_var;
 ERROR 42000: You have an error in your SQL syntax; check the manual that corresponds to your Drizzle server version for the right syntax to use near '; SELECT WILL_ERROR;' at line 1

=== added file 'tests/suite/regression/r/674719.result'
--- tests/suite/regression/r/674719.result	1970-01-01 00:00:00 +0000
+++ tests/suite/regression/r/674719.result	2011-02-03 07:17:37 +0000
@@ -0,0 +1,16 @@
+START TRANSACTION;
+START TRANSACTION;
+Warnings:
+Warning	1747	There is already a transaction in progress
+ROLLBACK;
+CREATE TABLE t1 (a int);
+START TRANSACTION;
+INSERT INTO t1 VALUES (1);
+START TRANSACTION;
+Warnings:
+Warning	1747	There is already a transaction in progress
+INSERT INTO t1 VALUES (2);
+ROLLBACK;
+SELECT * FROM t1;
+a
+DROP TABLE t1;

=== modified file 'tests/suite/regression/r/682563.result'
--- tests/suite/regression/r/682563.result	2011-01-21 19:31:02 +0000
+++ tests/suite/regression/r/682563.result	2011-02-03 07:17:37 +0000
@@ -145,6 +145,8 @@
 key1	value1
 key2	value2
 START TRANSACTION;
+Warnings:
+Warning	1747	There is already a transaction in progress
 INSERT INTO t1_trx VALUES ('key1','value1');
 INSERT INTO t1_trx VALUES ('key2','value2');
 SELECT t1_trx.k, t1_trx.v

=== added file 'tests/suite/regression/t/674719.test'
--- tests/suite/regression/t/674719.test	1970-01-01 00:00:00 +0000
+++ tests/suite/regression/t/674719.test	2011-02-03 02:46:18 +0000
@@ -0,0 +1,13 @@
+START TRANSACTION;
+START TRANSACTION;
+ROLLBACK;
+
+CREATE TABLE t1 (a int);
+START TRANSACTION;
+INSERT INTO t1 VALUES (1);
+START TRANSACTION;
+INSERT INTO t1 VALUES (2);
+ROLLBACK;
+SELECT * FROM t1;
+
+DROP TABLE t1;

